==> os_sys-0.0.0.tar.gz: os_sys-0.0.0/README.md <==
﻿include:
    introduction
    
    sorry                                                                                  
    	
    description                                                                                                                                                                    
    	
    license(at the end)
    home

introduction:
    to install extra_lib you type: pip install extra_lib                                                                                  
    to upgrade extra_lib you type: pip install --upgrade extra_lib                                                                                  
    so lets get start to install extra_lib                                                                                  

sorry:                                                                                  
    i am dutch and i never had a mind about it while become this far so some commands are in dutch.                                                                                  
    the most commands are english but sorry if you not understand some commands.                                                                                  
    the most new packages and update's while be in english                                                                                  

discription:                                                                                  
    extra_libs is a extra package for python(3)                                                                                  
    it's a extra to have a more easy use of the normal python libs                                                                                  
    plz look sometimes to my packages becuse i am making a own lib(extra is not that own lib)                                                                                  
    if i have more info i while show it here                                                                                  
    plz read the license                                                                                  
    
    



license:
    Copyright (c) 2018 The Python Packaging Authority

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"), to deal
    in the Software without restriction, including without limitation the rights
    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
    copies of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be included in all
    copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
    SOFTWARE.

home:
    plz visit my one website there you can post evry program for python that you want:
    https://python-libs-com.webnode.nl/

==> os_sys-0.0.1.tar.gz: os_sys-0.0.1/README.md <==
﻿include:

    introduction
    
    sorry                                                                                  
    	
    description                                                                                                                                                                    
    	
    license(at the end)
    home

introduction:


    to install os_sys you type: pip install os_sys                                                                                  
    to upgrade os_sys you type: pip install --upgrade os_sys                                                                                  
    so lets get start to install os_sys                                                                                  

sorry:                                                                                  
    i am dutch and i never had a mind about it while become this far so some commands are in dutch.                                                                                  
    the most commands are english but sorry if you not understand some commands.                                                                                  
    the most new packages and update's while be in english                                                                                  

discription:                                                                                  
    os_sys is a extra package for python(3)                                                                                  
    it's a extra to have a more easy use of the normal python libs                                                                                  
    plz look sometimes to my packages becuse i am making a own lib(extra is not that own lib)                                                                                  
    if i have more info i while show it here                                                                                  
    plz read the license                                                                                  
    
    



license:
    Copyright (c) 2018 The Python Packaging Authority

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"), to deal
    in the Software without restriction, including without limitation the rights
    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
    copies of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be included in all
    copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
    SOFTWARE.

home:
    plz visit my one website there you can post evry program for python that you want:
    https://python-libs-com.webnode.nl/
